@@ -69,6 +69,8 @@ class Search:
             lvl = 2
         if module and tag and key and value is not None:
             lvl = 1
+        if module and key and value is not None:
+            lvl = 0
 
         # Search by parameter of [module], [tag], [key] and [value].
         if lvl == 1:
@@ -96,4 +98,14 @@ class Search:
             except Exception:
                 pass
 
+        # Search by parameter of [module], [key] and [value].
+        if lvl == 0:
+            try:
+                for _tag in self.json[module]:
+                    for item in self.json[module][_tag]:
+                        if item.get(key) == value:
+                            return [item]
+            except Exception:
+                pass
+
         return output
