@@ -1,9 +1,9 @@
 from linux_profile.base.action import Action
-from linux_profile.base.config import Config
+from linux_profile.base.settings import Settings
 from linux_profile.handlers.package import HandlerPackage
 
 
-class Uninstall(Config):
+class Uninstall(Settings):
 
     def setup(self):
         """Defines the functions that are executed each
@@ -11,7 +11,7 @@ class Uninstall(Config):
         """
         self.command = self.__class__.__name__.lower()
         self.action = Action(
-            self.join([self.linuxp_path_config, self.linuxp_file_profile]))
+            str(self.path_profile.joinpath(self.file_profile)))
 
         func = self.join(value=[self.command, self.module], separator="_")
         getattr(self, func, self)()
